aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-rsvp.c
diff options
context:
space:
mode:
authorRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-21 04:49:01 +0000
committerRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2006-05-21 04:49:01 +0000
commitfeab79e32878302a87c7d22c52a2d5a255dbd3e9 (patch)
tree934f82dcbdd30f8c04d96b4215dbb0a6b8bc437e /epan/dissectors/packet-rsvp.c
parent58a0b106989d8278670d78fba86dd4585c3be52d (diff)
change a whole bunch of ethereal into wireshark
svn path=/trunk/; revision=18196
Diffstat (limited to 'epan/dissectors/packet-rsvp.c')
-rw-r--r--epan/dissectors/packet-rsvp.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/epan/dissectors/packet-rsvp.c b/epan/dissectors/packet-rsvp.c
index 095240f8fb..76a9891682 100644
--- a/epan/dissectors/packet-rsvp.c
+++ b/epan/dissectors/packet-rsvp.c
@@ -5,8 +5,8 @@
*
* $Id$
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
*
* This program is free software; you can redistribute it and/or
@@ -5199,7 +5199,7 @@ register_rsvp_prefs (void)
prefs_register_bool_preference(
rsvp_module, "process_bundle",
"Dissect sub-messages in BUNDLE message",
- "Specifies whether Ethereal should decode and display sub-messages within BUNDLE messages",
+ "Specifies whether Wireshark should decode and display sub-messages within BUNDLE messages",
&rsvp_bundle_dissect);
}
@@ -5,8 +5,8 @@
* $Id$
*
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
* Copyright 1998 Gerald Combs
*